<?php

namespace Drupal\error_reporting\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a controller for handling custom errors.
 */
class ErrorController extends ControllerBase {

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs an ErrorController object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(RendererInterface $renderer) {
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function handler(\Throwable $exception) {

    // Extract the error message from the exception.
    $message = $exception->getMessage();
    $line = $exception->getLine();
    $file = $exception->getFile();

    $build = [
      '#theme'   => 'custom_error_display',
      '#cache'   => ['max-age' => 0],
      '#message' => $message,
      '#file' => $file,
      '#line' => $line,
      '#trace' => [],
    ];

    $output = $this->renderer->renderRoot($build);

    print $output;
  }

}
